@@ -38,6 +38,7 @@
 #include "config.h"
 #include "common.h"
 #include <cupsfilters/image.h>
+#include <cupsfilters/raster.h>
 #include <math.h>
 #include <ctype.h>
 
@@ -401,8 +402,8 @@ static void outPrologue(int nPages)
 
 static void outPageObject(int pageObj, int contentsObj, int imgObj)
 {
-  int trfuncObj = newObj();
-  int lengthObj = newObj();
+  int trfuncObj;
+  int lengthObj;
   int startOffset;
   int length;
   int outTrfunc = (gammaval != 1.0 || brightness != 1.0);
@@ -420,8 +421,7 @@ static void outPageObject(int pageObj, int contentsObj, int imgObj)
     "/TrimBox [ 0 0 %f %f ] ",PageWidth,PageLength);
   outPdf(linebuf);
   snprintf(linebuf,LINEBUFSIZE,
-    "/CropBox [ %f %f %f %f ] ",
-    PageLeft,PageBottom,PageRight,PageTop);
+    "/CropBox [ 0 0 %f %f ] ",PageWidth,PageLength);
   outPdf(linebuf);
   if (contentsObj >= 0) {
     snprintf(linebuf,LINEBUFSIZE,
@@ -438,6 +438,8 @@ static void outPageObject(int pageObj, int contentsObj, int imgObj)
     outPdf(linebuf);
   }
   if (outTrfunc) {
+    trfuncObj = newObj();
+    lengthObj = newObj();
     snprintf(linebuf,LINEBUFSIZE,
       "/ExtGState << /GS1 << /TR %d 0 R >> >>\n",trfuncObj);
     outPdf(linebuf);
@@ -690,6 +692,9 @@ int					/* O - Exit status */
 main(int  argc,				/* I - Number of command-line arguments */
      char *argv[])			/* I - Command-line arguments */
 {
+  cups_page_header2_t h;                /* CUPS Raster page header, to */
+                                        /* accommodate results of command */
+                                        /* line parsing for PPD-less queue */
   ppd_choice_t	*choice;		/* PPD option choice */
   int		num_options;		/* Number of print options */
   cups_option_t	*options;		/* Print options */
@@ -723,10 +728,8 @@ main(int  argc,				/* I - Number of command-line arguments */
   }
 
   title = argv[3];
-#ifdef DEBUG
   fprintf(stderr, "INFO: %s %s %s %s %s %s %s\n", argv[0], argv[1], argv[2],
           argv[3], argv[4], argv[5], argv[6] ? argv[6] : "(null)");
-#endif
 
  /*
   * Copy stdin as needed...
@@ -745,10 +748,8 @@ main(int  argc,				/* I - Number of command-line arguments */
       return (1);
     }
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: imagetopdf - copying to temp print file \"%s\"\n",
             filename);
-#endif
 
     while ((bytes = fread(buffer, 1, sizeof(buffer), stdin)) > 0)
       write(fd, buffer, bytes);
@@ -776,6 +777,27 @@ main(int  argc,				/* I - Number of command-line arguments */
   num_options = cupsParseOptions(argv[5], 0, &options);
 
   ppd = SetCommonOptions(num_options, options, 0);
+  if (!ppd) {
+    cupsRasterParseIPPOptions(&h, num_options, options, 0, 1);
+    Orientation = h.Orientation;
+    Duplex = h.Duplex;
+    ColorDevice = h.cupsNumColors <= 1 ? 0 : 1;
+    PageWidth = h.cupsPageSize[0] != 0.0 ? h.cupsPageSize[0] :
+      (float)h.PageSize[0];
+    PageLength = h.cupsPageSize[1] != 0.0 ? h.cupsPageSize[1] :
+      (float)h.PageSize[1];
+    PageLeft = h.cupsImagingBBox[0] != 0.0 ? h.cupsImagingBBox[0] :
+      (float)h.ImagingBoundingBox[0];
+    PageBottom = h.cupsImagingBBox[1] != 0.0 ? h.cupsImagingBBox[1] :
+      (float)h.ImagingBoundingBox[1];
+    PageRight = h.cupsImagingBBox[2] != 0.0 ? h.cupsImagingBBox[2] :
+      (float)h.ImagingBoundingBox[2];
+    PageTop = h.cupsImagingBBox[3] != 0.0 ? h.cupsImagingBBox[3] :
+      (float)h.ImagingBoundingBox[3];
+    Flip = h.MirrorPrint ? 1 : 0;
+    Collate = h.Collate ? 1 : 0;
+    Copies = h.NumCopies;
+  }
 
   if (Copies == 1
       && (choice = ppdFindMarkedChoice(ppd,"Copies")) != NULL) {
@@ -1015,10 +1037,8 @@ main(int  argc,				/* I - Number of command-line arguments */
   if (yppi == 0)
     yppi = xppi;
 
-#ifdef DEBUG
   fprintf(stderr, "DEBUG: Before scaling: xppi=%d, yppi=%d, zoom=%.2f\n",
           xppi, yppi, zoom);
-#endif
 
   if (xppi > 0)
   {
@@ -1037,18 +1057,14 @@ main(int  argc,				/* I - Number of command-line arguments */
       yprint = (PageTop - PageBottom) / 72.0;
     }
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: Before scaling: xprint=%.1f, yprint=%.1f\n",
             xprint, yprint);
-#endif
 
     xinches = (float)cupsImageGetWidth(img) / (float)xppi;
     yinches = (float)cupsImageGetHeight(img) / (float)yppi;
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: Image size is %.1f x %.1f inches...\n",
             xinches, yinches);
-#endif
 
     if ((val = cupsGetOption("natural-scaling", num_options, options)) != NULL)
     {
@@ -1063,9 +1079,7 @@ main(int  argc,				/* I - Number of command-line arguments */
       * Rotate the image if it will fit landscape but not portrait...
       */
 
-#ifdef DEBUG
       fputs("DEBUG: Auto orientation...\n", stderr);
-#endif
 
       if ((xinches > xprint || yinches > yprint) &&
           xinches <= yprint && yinches <= xprint)
@@ -1074,9 +1088,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	* Rotate the image as needed...
 	*/
 
-#ifdef DEBUG
         fputs("DEBUG: Using landscape orientation...\n", stderr);
-#endif
 
 	Orientation = (Orientation + 1) & 3;
 	xsize       = yprint;
@@ -1095,13 +1107,11 @@ main(int  argc,				/* I - Number of command-line arguments */
     yprint = (PageTop - PageBottom) / 72.0;
     aspect = (float)cupsImageGetYPPI(img) / (float)cupsImageGetXPPI(img);
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: Before scaling: xprint=%.1f, yprint=%.1f\n",
             xprint, yprint);
 
     fprintf(stderr, "DEBUG: cupsImageGetXPPI(img) = %d, cupsImageGetYPPI(img) = %d, aspect = %f\n",
             cupsImageGetXPPI(img), cupsImageGetYPPI(img), aspect);
-#endif
 
     xsize = xprint * zoom;
     ysize = xsize * cupsImageGetHeight(img) / cupsImageGetWidth(img) / aspect;
@@ -1121,10 +1131,8 @@ main(int  argc,				/* I - Number of command-line arguments */
       xsize2 = ysize2 * cupsImageGetWidth(img) * aspect / cupsImageGetHeight(img);
     }
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: Portrait size is %.2f x %.2f inches\n", xsize, ysize);
     fprintf(stderr, "DEBUG: Landscape size is %.2f x %.2f inches\n", xsize2, ysize2);
-#endif
 
     if (cupsGetOption("orientation-requested", num_options, options) == NULL &&
         cupsGetOption("landscape", num_options, options) == NULL)
@@ -1134,9 +1142,7 @@ main(int  argc,				/* I - Number of command-line arguments */
       * portrait if they are equal...
       */
 
-#ifdef DEBUG
       fputs("DEBUG: Auto orientation...\n", stderr);
-#endif
 
       if ((xsize * ysize) < (xsize2 * xsize2))
       {
@@ -1144,9 +1150,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	* Do landscape orientation...
 	*/
 
-#ifdef DEBUG
         fputs("DEBUG: Using landscape orientation...\n", stderr);
-#endif
 
 	Orientation = 1;
 	xinches     = xsize2;
@@ -1160,9 +1164,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	* Do portrait orientation...
 	*/
 
-#ifdef DEBUG
         fputs("DEBUG: Using portrait orientation...\n", stderr);
-#endif
 
 	Orientation = 0;
 	xinches     = xsize;
@@ -1171,9 +1173,7 @@ main(int  argc,				/* I - Number of command-line arguments */
     }
     else if (Orientation & 1)
     {
-#ifdef DEBUG
       fputs("DEBUG: Using landscape orientation...\n", stderr);
-#endif
 
       xinches     = xsize2;
       yinches     = ysize2;
@@ -1182,9 +1182,7 @@ main(int  argc,				/* I - Number of command-line arguments */
     }
     else
     {
-#ifdef DEBUG
       fputs("DEBUG: Using portrait orientation...\n", stderr);
-#endif
 
       xinches     = xsize;
       yinches     = ysize;
@@ -1212,10 +1210,8 @@ main(int  argc,				/* I - Number of command-line arguments */
   xprint = xinches / xpages;
   yprint = yinches / ypages;
 
-#ifdef DEBUG
   fprintf(stderr, "DEBUG: xpages = %dx%.2fin, ypages = %dx%.2fin\n",
           xpages, xprint, ypages, yprint);
-#endif
 
  /*
   * Update the page size for custom sizes...
@@ -1261,10 +1257,8 @@ main(int  argc,				/* I - Number of command-line arguments */
     if (length < ppd->custom_min[1])
       length = ppd->custom_min[1];
 
-#ifdef DEBUG
     fprintf(stderr, "DEBUG: Updated custom page size to %.2f x %.2f inches...\n",
             width / 72.0, length / 72.0);
-#endif
 
    /*
     * Set the new custom size...
@@ -1451,7 +1445,6 @@ main(int  argc,				/* I - Number of command-line arguments */
 
   row = malloc(cupsImageGetWidth(img) * abs(colorspace) + 3);
 
-#ifdef DEBUG
   fprintf(stderr, "DEBUG: XPosition=%d, YPosition=%d, Orientation=%d\n",
           XPosition, YPosition, Orientation);
   fprintf(stderr, "DEBUG: xprint=%.0f, yprint=%.0f\n", xprint, yprint);
@@ -1459,7 +1452,6 @@ main(int  argc,				/* I - Number of command-line arguments */
           PageLeft, PageRight, PageWidth);
   fprintf(stderr, "DEBUG: PageBottom=%.0f, PageTop=%.0f, PageLength=%.0f\n",
           PageBottom, PageTop, PageLength);
-#endif
 
   if (Flip) {
     pr = PageWidth - PageLeft;
@@ -1584,9 +1576,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	break;
   }
 
-#ifdef DEBUG
   fprintf(stderr, "DEBUG: left=%.2f, top=%.2f\n", left, top);
-#endif
 
   if (Collate)
   {
